@@ -10,15 +10,15 @@
 #ifndef __PACKET_BLUETOOTH_H__
 #define __PACKET_BLUETOOTH_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
 #include <epan/wmem/wmem.h>
 
 #include "packet-usb.h"
 #include "packet-ubertooth.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #define PROTO_DATA_BLUETOOTH_SERVICE_UUID  0
 
 #define BLUETOOTH_DATA_SRC 0
@@ -28,6 +28,7 @@ extern "C" {
 #define HCI_H4_TYPE_ACL   0x02
 #define HCI_H4_TYPE_SCO   0x03
 #define HCI_H4_TYPE_EVT   0x04
+#define HCI_H4_TYPE_ISO   0x05
 
 #define HCI_OGF_LINK_CONTROL           0x01
 #define HCI_OGF_LINK_POLICY            0x02
@@ -87,6 +88,7 @@ typedef enum {
 /* chandle_sessions:         interface_id + adapter_id + connection_handle + frame_number -> connect_in_frame, disconnect_in_frame */
 /* chandle_to_bdaddr:        interface_id + adapter_id + connection_handle + frame_number -> bd_addr[6] */
 /* chandle_to_mode:          interface_id + adapter_id + connection_handle + frame_number -> mode */
+/* shandle_to_chandle:       interface_id + adapter_id + stream_handle + frame_number -> connection_handle */
 /* bdaddr_to_name:           bd_addr[6] + frame_number -> name */
 /* bdaddr_to_role:           bd_addr[6] + frame_number -> role */
 /* localhost_bdaddr:         interface_id + adapter_id + frame_number -> bd_addr[6] */
@@ -98,6 +100,7 @@ typedef struct _bluetooth_data_t {
     wmem_tree_t *chandle_sessions;
     wmem_tree_t *chandle_to_bdaddr;
     wmem_tree_t *chandle_to_mode;
+    wmem_tree_t *shandle_to_chandle;
     wmem_tree_t *bdaddr_to_name;
     wmem_tree_t *bdaddr_to_role;
     wmem_tree_t *localhost_bdaddr;
@@ -119,6 +122,7 @@ typedef struct _bluetooth_data_t {
 #define BT_LINK_TYPE_ACL     1
 #define BT_LINK_TYPE_SCO     2
 #define BT_LINK_TYPE_LL      3
+#define BT_LINK_TYPE_ISO     4
 
 typedef struct _chandle_session_t {
     guint32  connect_in_frame;
@@ -149,6 +153,11 @@ typedef struct _connection_mode_t {
     guint32  change_in_frame;
 } connection_mode_t;
 
+typedef struct _stream_connection_handle_pair_t {
+    gint32   chandle;
+    guint32  change_in_frame;
+} stream_connection_handle_pair_t;
+
 #define ROLE_UNKNOWN  0
 #define ROLE_MASTER   1
 #define ROLE_SLAVE    2
@@ -241,7 +250,9 @@ typedef struct _bluetooth_device_tap_t {
         } mtus;
         struct {
             guint16  acl_mtu;
+            guint16  iso_mtu;
             guint16  acl_packets;
+            guint16  iso_packets;
         } le_mtus;
     } data;
 } bluetooth_device_tap_t;
